# For the latest code

Primary development is on Github, see
[https://github.com/PySCeS/pysces](https://github.com/PySCeS/pysces). Feel free to
fork and submit pull requests!

```
git clone git@github.com:PySCeS/pysces.git
```

PySCeS binaries for release versions are available from PyPI and the Anaconda.org 
for 64-bit Windows, Linux and macOS.

**For PyPI:**

```
pip install pysces
```

**For Anaconda:**

```
conda install -c sbmlteam -c pysces pysces
```

© Brett G. Olivier & Johann M. Rohwer, August 2021
